@@ -19,8 +19,10 @@
 #include "../logunit.h"
 #include "../insertwide.h"
 #include <log4cxx/helpers/bytebuffer.h>
+#include <log4cxx/helpers/transcoder.h>
+#include <log4cxx/helpers/loglog.h>
 #include <apr.h>
-#include <apr_atomic.h>
+#include <apr_errno.h>
 #include <condition_variable>
 #include <thread>
 
@@ -35,9 +37,8 @@ LOGUNIT_CLASS(CharsetEncoderTestCase)
 	LOGUNIT_TEST(encode2);
 	LOGUNIT_TEST(encode3);
 	LOGUNIT_TEST(encode4);
-#if APR_HAS_THREADS
+	LOGUNIT_TEST(encode5);
 	LOGUNIT_TEST(thread1);
-#endif
 	LOGUNIT_TEST_SUITE_END();
 
 	enum { BUFSIZE = 256 };
@@ -178,12 +179,67 @@ public:
 		LOGUNIT_ASSERT(iter == greeting.end());
 	}
 
-#if APR_HAS_THREADS
+	void encode5()
+	{
+		const char utf8_greet[] = { 'A',
+				(char) 0xD8, (char) 0x85,
+				(char) 0xD4, (char) 0xB0,
+				(char) 0xE0, (char) 0xA6, (char) 0x86,
+				(char) 0xE4, (char) 0xB8, (char) 0x83,
+				(char) 0xD0, (char) 0x80,
+				0
+			};
+#if LOG4CXX_LOGCHAR_IS_WCHAR || LOG4CXX_LOGCHAR_IS_UNICHAR
+		//   arbitrary, hopefully meaningless, characters from
+		//     Latin, Arabic, Armenian, Bengali, CJK and Cyrillic
+		const logchar greet[] = { L'A', 0x0605, 0x0530, 0x986, 0x4E03, 0x400, 0 };
+#endif
+
+#if LOG4CXX_LOGCHAR_IS_UTF8
+		const logchar* greet = utf8_greet;
+#endif
+		LogString greeting(greet);
+
+		try
+		{
+			std::locale::global(std::locale("en_US.UTF-8"));
+			auto enc = CharsetEncoder::getEncoder(LOG4CXX_STR("locale"));
+
+			char buf[BUFSIZE];
+			ByteBuffer out(buf, BUFSIZE);
+			LogString::const_iterator iter = greeting.begin();
+			log4cxx_status_t stat = enc->encode(greeting, iter, out);
+			LOGUNIT_ASSERT_EQUAL(false, CharsetEncoder::isError(stat));
+			stat = enc->encode(greeting, iter, out);
+			LOGUNIT_ASSERT_EQUAL(false, CharsetEncoder::isError(stat));
+
+			out.flip();
+			LOGUNIT_ASSERT_EQUAL((size_t) 13, out.limit());
+
+			for (size_t i = 0; i < out.limit(); i++)
+			{
+				unsigned expected = (unsigned)utf8_greet[i];
+				unsigned actual = (unsigned)out.data()[i];
+				LOGUNIT_ASSERT_EQUAL(expected, actual);
+			}
+
+			LOGUNIT_ASSERT(iter == greeting.end());
+		}
+		catch (std::runtime_error& ex)
+		{
+			LogString msg;
+			Transcoder::decode(ex.what(), msg);
+			msg.append(LOG4CXX_STR(": "));
+			msg.append(LOG4CXX_STR("en_US.UTF-8"));
+			LogLog::warn(msg);
+		}
+	}
+
 	class ThreadPackage
 	{
 		public:
-			ThreadPackage(CharsetEncoderPtr& enc, int repetitions) :
-				p(), passCount(0), failCount(0), enc(enc), repetitions(repetitions)
+			ThreadPackage(CharsetEncoderPtr& enc, int repetitions)
+				: passCount(0), failCount(0), enc(enc), repetitions(repetitions)
 			{
 			}
 
@@ -201,22 +257,26 @@ public:
 
 			void fail()
 			{
-				apr_atomic_inc32(&failCount);
+				std::lock_guard<std::mutex> sync(lock);
+				++failCount;
 			}
 
 			void pass()
 			{
-				apr_atomic_inc32(&passCount);
+				std::lock_guard<std::mutex> sync(lock);
+				++passCount;
 			}
 
-			apr_uint32_t getFail()
+			uint32_t getFail()
 			{
-				return apr_atomic_read32(&failCount);
+				std::lock_guard<std::mutex> sync(lock);
+				return failCount;
 			}
 
-			apr_uint32_t getPass()
+			uint32_t getPass()
 			{
-				return apr_atomic_read32(&passCount);
+				std::lock_guard<std::mutex> sync(lock);
+				return passCount;
 			}
 
 			int getRepetitions()
@@ -297,11 +357,10 @@ public:
 		private:
 			ThreadPackage(const ThreadPackage&);
 			ThreadPackage& operator=(ThreadPackage&);
-			Pool p;
 			std::mutex lock;
 			std::condition_variable condition;
-			volatile apr_uint32_t passCount;
-			volatile apr_uint32_t failCount;
+			uint32_t passCount;
+			uint32_t failCount;
 			CharsetEncoderPtr enc;
 			int repetitions;
 	};
@@ -311,12 +370,10 @@ public:
 		enum { THREAD_COUNT = 10, THREAD_REPS = 10000 };
 		std::thread threads[THREAD_COUNT];
 		CharsetEncoderPtr enc(CharsetEncoder::getEncoder(LOG4CXX_STR("ISO-8859-1")));
-		ThreadPackage* package = new ThreadPackage(enc, THREAD_REPS);
+		auto package = std::make_unique<ThreadPackage>(enc, THREAD_REPS);
+		for (int i = 0; i < THREAD_COUNT; i++)
 		{
-			for (int i = 0; i < THREAD_COUNT; i++)
-			{
-				threads[i] = std::thread(&ThreadPackage::run, package);
-			}
+			threads[i] = std::thread(&ThreadPackage::run, package.get());
 		}
 		//
 		//   give time for all threads to be launched so
@@ -331,9 +388,7 @@ public:
 
 		LOGUNIT_ASSERT_EQUAL((apr_uint32_t) 0, package->getFail());
 		LOGUNIT_ASSERT_EQUAL((apr_uint32_t) THREAD_COUNT * THREAD_REPS, package->getPass());
-		delete package;
 	}
-#endif
 
 };
 
