@@ -17,7 +17,7 @@
 
 #include <log4cxx/log4cxx.h>
  /* Prevent error C2491: 'std::numpunct<_Elem>::id': definition of dllimport static data member not allowed */
-#if defined(_MSC_VER) && (LOG4CXX_UNICHAR_API || LOG4CXX_CFSTRING_API)
+#if defined(_MSC_VER) && LOG4CXX_UNICHAR_API
 #define __FORCE_INSTANCE
 #endif
 #include <ostream>
@@ -30,6 +30,7 @@
 #include "insertwide.h"
 #include "logunit.h"
 #include <log4cxx/stream.h>
+#include <log4cxx/helpers/loglog.h>
 
 #if LOG4CXX_CFSTRING_API
 	#include <CoreFoundation/CFString.h>
@@ -121,6 +122,8 @@ LOGUNIT_CLASS(StreamTestCase)
 #if LOG4CXX_CFSTRING_API
 	LOGUNIT_TEST(testCFString);
 	LOGUNIT_TEST(testCFStringAppend);
+#endif
+#if LOG4CXX_UNICHAR_API && LOG4CXX_CFSTRING_API
 	LOGUNIT_TEST(testULogStreamCFString);
 	LOGUNIT_TEST(testULogStreamCFString2);
 #endif
@@ -128,6 +131,15 @@ LOGUNIT_CLASS(StreamTestCase)
 
 	VectorAppenderPtr vectorAppender;
 
+#ifdef _DEBUG
+	struct Fixture
+	{
+		Fixture() {
+			helpers::LogLog::setInternalDebugging(true);
+		}
+	} suiteFixture;
+#endif
+
 public:
 	void setUp()
 	{
@@ -623,17 +635,19 @@ public:
 	void testCFString()
 	{
 		LoggerPtr root(Logger::getRootLogger());
-		LOG4CXX_INFO(root, CFSTR("This is a test"))
+		LOG4CXX_INFO(root, CFSTR("This is a test"));
 		LOGUNIT_ASSERT_EQUAL((size_t) 1, vectorAppender->getVector().size());
 	}
 
 	void testCFStringAppend()
 	{
 		LoggerPtr root(Logger::getRootLogger());
-		LOG4CXX_INFO(root, CFSTR("This is a test") << CFSTR(": Details to follow"))
+		LOG4CXX_INFO(root, CFSTR("This is a test") << CFSTR(": Details to follow"));
 		LOGUNIT_ASSERT_EQUAL((size_t) 1, vectorAppender->getVector().size());
 	}
+#endif
 
+#if LOG4CXX_UNICHAR_API && LOG4CXX_CFSTRING_API
 	void testULogStreamCFString()
 	{
 		ulogstream root(Logger::getRootLogger(), Level::getInfo());
